"""
Module: '_api.colorsensor' on micropython-v1.14-893-lego learning system hub
"""
# MCU: {'machine': 'LEGO Technic Large Hub with STM32F413xx', 'sysname': 'LEGO Technic Large Hub', 'platform': 'LEGO Learning System Hub', 'nodename': 'LEGO Learning System Hub', 'ver': 'v1.14-893', 'release': '1.14.0', 'name': 'micropython', 'family': 'micropython', 'port': 'LEGO Learning System Hub', 'version': '1.14.0', 'mpy': 517, 'build': '893'}
# Stubber: 1.7.2
from typing import Any


class ColorSensor():
    def __init__(self, *argv, **kwargs) -> None:
        """"""

    def get_ambient_light(self, *args, **kwargs) -> Any:
        """"""

    def get_blue(self, *args, **kwargs) -> Any:
        """"""

    def get_color(self, *args, **kwargs) -> Any:
        """"""

    def get_green(self, *args, **kwargs) -> Any:
        """"""

    def get_red(self, *args, **kwargs) -> Any:
        """"""

    def get_reflected_light(self, *args, **kwargs) -> Any:
        """"""

    def get_rgb_intensity(self, *args, **kwargs) -> Any:
        """"""

    def light_up(self, *args, **kwargs) -> Any:
        """"""

    def light_up_all(self, *args, **kwargs) -> Any:
        """"""

    def wait_for_new_color(self, *args, **kwargs) -> Any:
        """"""

    def wait_until_color(self, *args, **kwargs) -> Any:
        """"""

LPF2_FLIPPER_COLOR = 61 # type: int
PORTS = {} # type: dict
def clamp(*args, **kwargs) -> Any:
    """"""

def get_sensor_value(*args, **kwargs) -> Any:
    """"""

def is_type(*args, **kwargs) -> Any:
    """"""

def newSensorDisconnectedError(*args, **kwargs) -> Any:
    """"""

def sleep_ms(*args, **kwargs) -> Any:
    """"""

